cumulusci.cli.tests package
===========================

Submodules
----------

cumulusci.cli.tests.test\_cci module
------------------------------------

.. automodule:: cumulusci.cli.tests.test_cci
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.cli.tests.test\_config module
---------------------------------------

.. automodule:: cumulusci.cli.tests.test_config
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.cli.tests.test\_logger module
---------------------------------------

.. automodule:: cumulusci.cli.tests.test_logger
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.cli.tests
    :members:
    :undoc-members:
    :show-inheritance:
